/* this ALWAYS GENERATED file contains the definitions for the interfaces */


/* File created by MIDL compiler version 3.01.75 */
/* at Wed Aug 20 10:16:53 1997
 */
/* Compiler settings for atltimer.idl:
    Oicf (OptLev=i2), W1, Zp8, env=Win32, ms_ext, c_ext
    error checks: none
*/
//@@MIDL_FILE_HEADING(  )
#include "rpc.h"
#include "rpcndr.h"
#ifndef COM_NO_WINDOWS_H
#include "windows.h"
#include "ole2.h"
#endif /*COM_NO_WINDOWS_H*/

#ifndef __atltimer_h__
#define __atltimer_h__

#ifdef __cplusplus
extern "C"{
#endif 

/* Forward Declarations */ 

#ifndef __IAtlTimerCtrl_FWD_DEFINED__
#define __IAtlTimerCtrl_FWD_DEFINED__
typedef interface IAtlTimerCtrl IAtlTimerCtrl;
#endif 	/* __IAtlTimerCtrl_FWD_DEFINED__ */


#ifndef ___IAtlTimerCtrlEvents_FWD_DEFINED__
#define ___IAtlTimerCtrlEvents_FWD_DEFINED__
typedef interface _IAtlTimerCtrlEvents _IAtlTimerCtrlEvents;
#endif 	/* ___IAtlTimerCtrlEvents_FWD_DEFINED__ */


#ifndef __AtlTimerCtrl_FWD_DEFINED__
#define __AtlTimerCtrl_FWD_DEFINED__

#ifdef __cplusplus
typedef class AtlTimerCtrl AtlTimerCtrl;
#else
typedef struct AtlTimerCtrl AtlTimerCtrl;
#endif /* __cplusplus */

#endif 	/* __AtlTimerCtrl_FWD_DEFINED__ */


#ifndef __AtlTimerProp_FWD_DEFINED__
#define __AtlTimerProp_FWD_DEFINED__

#ifdef __cplusplus
typedef class AtlTimerProp AtlTimerProp;
#else
typedef struct AtlTimerProp AtlTimerProp;
#endif /* __cplusplus */

#endif 	/* __AtlTimerProp_FWD_DEFINED__ */


/* header files for imported files */
#include "oaidl.h"
#include "ocidl.h"

void __RPC_FAR * __RPC_USER MIDL_user_allocate(size_t);
void __RPC_USER MIDL_user_free( void __RPC_FAR * ); 

#ifndef __IAtlTimerCtrl_INTERFACE_DEFINED__
#define __IAtlTimerCtrl_INTERFACE_DEFINED__

/****************************************
 * Generated header for interface: IAtlTimerCtrl
 * at Wed Aug 20 10:16:53 1997
 * using MIDL 3.01.75
 ****************************************/
/* [unique][helpstring][dual][uuid][object] */ 



EXTERN_C const IID IID_IAtlTimerCtrl;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    interface DECLSPEC_UUID("90EB88BD-1956-11D1-917B-00608C86B89C")
    IAtlTimerCtrl : public IDispatch
    {
    public:
        virtual /* [id][propput] */ HRESULT STDMETHODCALLTYPE put_BackColor( 
            /* [in] */ OLE_COLOR clr) = 0;
        
        virtual /* [id][propget] */ HRESULT STDMETHODCALLTYPE get_BackColor( 
            /* [retval][out] */ OLE_COLOR __RPC_FAR *pclr) = 0;
        
        virtual /* [helpstring][id][propget] */ HRESULT STDMETHODCALLTYPE get_ShowSeconds( 
            /* [retval][out] */ BOOL __RPC_FAR *pVal) = 0;
        
        virtual /* [helpstring][id][propput] */ HRESULT STDMETHODCALLTYPE put_ShowSeconds( 
            /* [in] */ BOOL newVal) = 0;
        
        virtual /* [helpstring][id] */ HRESULT STDMETHODCALLTYPE SetAlarm( 
            long SecondsToWait) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IAtlTimerCtrlVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE __RPC_FAR *QueryInterface )( 
            IAtlTimerCtrl __RPC_FAR * This,
            /* [in] */ REFIID riid,
            /* [iid_is][out] */ void __RPC_FAR *__RPC_FAR *ppvObject);
        
        ULONG ( STDMETHODCALLTYPE __RPC_FAR *AddRef )( 
            IAtlTimerCtrl __RPC_FAR * This);
        
        ULONG ( STDMETHODCALLTYPE __RPC_FAR *Release )( 
            IAtlTimerCtrl __RPC_FAR * This);
        
        HRESULT ( STDMETHODCALLTYPE __RPC_FAR *GetTypeInfoCount )( 
            IAtlTimerCtrl __RPC_FAR * This,
            /* [out] */ UINT __RPC_FAR *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE __RPC_FAR *GetTypeInfo )( 
            IAtlTimerCtrl __RPC_FAR * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo __RPC_FAR *__RPC_FAR *ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE __RPC_FAR *GetIDsOfNames )( 
            IAtlTimerCtrl __RPC_FAR * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR __RPC_FAR *rgszNames,
            /* [in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID __RPC_FAR *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE __RPC_FAR *Invoke )( 
            IAtlTimerCtrl __RPC_FAR * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS __RPC_FAR *pDispParams,
            /* [out] */ VARIANT __RPC_FAR *pVarResult,
            /* [out] */ EXCEPINFO __RPC_FAR *pExcepInfo,
            /* [out] */ UINT __RPC_FAR *puArgErr);
        
        /* [id][propput] */ HRESULT ( STDMETHODCALLTYPE __RPC_FAR *put_BackColor )( 
            IAtlTimerCtrl __RPC_FAR * This,
            /* [in] */ OLE_COLOR clr);
        
        /* [id][propget] */ HRESULT ( STDMETHODCALLTYPE __RPC_FAR *get_BackColor )( 
            IAtlTimerCtrl __RPC_FAR * This,
            /* [retval][out] */ OLE_COLOR __RPC_FAR *pclr);
        
        /* [helpstring][id][propget] */ HRESULT ( STDMETHODCALLTYPE __RPC_FAR *get_ShowSeconds )( 
            IAtlTimerCtrl __RPC_FAR * This,
            /* [retval][out] */ BOOL __RPC_FAR *pVal);
        
        /* [helpstring][id][propput] */ HRESULT ( STDMETHODCALLTYPE __RPC_FAR *put_ShowSeconds )( 
            IAtlTimerCtrl __RPC_FAR * This,
            /* [in] */ BOOL newVal);
        
        /* [helpstring][id] */ HRESULT ( STDMETHODCALLTYPE __RPC_FAR *SetAlarm )( 
            IAtlTimerCtrl __RPC_FAR * This,
            long SecondsToWait);
        
        END_INTERFACE
    } IAtlTimerCtrlVtbl;

    interface IAtlTimerCtrl
    {
        CONST_VTBL struct IAtlTimerCtrlVtbl __RPC_FAR *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IAtlTimerCtrl_QueryInterface(This,riid,ppvObject)	\
    (This)->lpVtbl -> QueryInterface(This,riid,ppvObject)

#define IAtlTimerCtrl_AddRef(This)	\
    (This)->lpVtbl -> AddRef(This)

#define IAtlTimerCtrl_Release(This)	\
    (This)->lpVtbl -> Release(This)


#define IAtlTimerCtrl_GetTypeInfoCount(This,pctinfo)	\
    (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo)

#define IAtlTimerCtrl_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo)

#define IAtlTimerCtrl_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)

#define IAtlTimerCtrl_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)


#define IAtlTimerCtrl_put_BackColor(This,clr)	\
    (This)->lpVtbl -> put_BackColor(This,clr)

#define IAtlTimerCtrl_get_BackColor(This,pclr)	\
    (This)->lpVtbl -> get_BackColor(This,pclr)

#define IAtlTimerCtrl_get_ShowSeconds(This,pVal)	\
    (This)->lpVtbl -> get_ShowSeconds(This,pVal)

#define IAtlTimerCtrl_put_ShowSeconds(This,newVal)	\
    (This)->lpVtbl -> put_ShowSeconds(This,newVal)

#define IAtlTimerCtrl_SetAlarm(This,SecondsToWait)	\
    (This)->lpVtbl -> SetAlarm(This,SecondsToWait)

#endif /* COBJMACROS */


#endif 	/* C style interface */



/* [id][propput] */ HRESULT STDMETHODCALLTYPE IAtlTimerCtrl_put_BackColor_Proxy( 
    IAtlTimerCtrl __RPC_FAR * This,
    /* [in] */ OLE_COLOR clr);


void __RPC_STUB IAtlTimerCtrl_put_BackColor_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [id][propget] */ HRESULT STDMETHODCALLTYPE IAtlTimerCtrl_get_BackColor_Proxy( 
    IAtlTimerCtrl __RPC_FAR * This,
    /* [retval][out] */ OLE_COLOR __RPC_FAR *pclr);


void __RPC_STUB IAtlTimerCtrl_get_BackColor_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpstring][id][propget] */ HRESULT STDMETHODCALLTYPE IAtlTimerCtrl_get_ShowSeconds_Proxy( 
    IAtlTimerCtrl __RPC_FAR * This,
    /* [retval][out] */ BOOL __RPC_FAR *pVal);


void __RPC_STUB IAtlTimerCtrl_get_ShowSeconds_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpstring][id][propput] */ HRESULT STDMETHODCALLTYPE IAtlTimerCtrl_put_ShowSeconds_Proxy( 
    IAtlTimerCtrl __RPC_FAR * This,
    /* [in] */ BOOL newVal);


void __RPC_STUB IAtlTimerCtrl_put_ShowSeconds_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpstring][id] */ HRESULT STDMETHODCALLTYPE IAtlTimerCtrl_SetAlarm_Proxy( 
    IAtlTimerCtrl __RPC_FAR * This,
    long SecondsToWait);


void __RPC_STUB IAtlTimerCtrl_SetAlarm_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);



#endif 	/* __IAtlTimerCtrl_INTERFACE_DEFINED__ */



#ifndef __ATLTIMERLib_LIBRARY_DEFINED__
#define __ATLTIMERLib_LIBRARY_DEFINED__

/****************************************
 * Generated header for library: ATLTIMERLib
 * at Wed Aug 20 10:16:53 1997
 * using MIDL 3.01.75
 ****************************************/
/* [helpstring][version][uuid] */ 



EXTERN_C const IID LIBID_ATLTIMERLib;

#ifndef ___IAtlTimerCtrlEvents_DISPINTERFACE_DEFINED__
#define ___IAtlTimerCtrlEvents_DISPINTERFACE_DEFINED__

/****************************************
 * Generated header for dispinterface: _IAtlTimerCtrlEvents
 * at Wed Aug 20 10:16:53 1997
 * using MIDL 3.01.75
 ****************************************/
/* [helpstring][uuid] */ 



EXTERN_C const IID DIID__IAtlTimerCtrlEvents;

#if defined(__cplusplus) && !defined(CINTERFACE)

    interface DECLSPEC_UUID("90EB88BE-1956-11D1-917B-00608C86B89C")
    _IAtlTimerCtrlEvents : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct _IAtlTimerCtrlEventsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE __RPC_FAR *QueryInterface )( 
            _IAtlTimerCtrlEvents __RPC_FAR * This,
            /* [in] */ REFIID riid,
            /* [iid_is][out] */ void __RPC_FAR *__RPC_FAR *ppvObject);
        
        ULONG ( STDMETHODCALLTYPE __RPC_FAR *AddRef )( 
            _IAtlTimerCtrlEvents __RPC_FAR * This);
        
        ULONG ( STDMETHODCALLTYPE __RPC_FAR *Release )( 
            _IAtlTimerCtrlEvents __RPC_FAR * This);
        
        HRESULT ( STDMETHODCALLTYPE __RPC_FAR *GetTypeInfoCount )( 
            _IAtlTimerCtrlEvents __RPC_FAR * This,
            /* [out] */ UINT __RPC_FAR *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE __RPC_FAR *GetTypeInfo )( 
            _IAtlTimerCtrlEvents __RPC_FAR * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo __RPC_FAR *__RPC_FAR *ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE __RPC_FAR *GetIDsOfNames )( 
            _IAtlTimerCtrlEvents __RPC_FAR * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR __RPC_FAR *rgszNames,
            /* [in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID __RPC_FAR *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE __RPC_FAR *Invoke )( 
            _IAtlTimerCtrlEvents __RPC_FAR * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS __RPC_FAR *pDispParams,
            /* [out] */ VARIANT __RPC_FAR *pVarResult,
            /* [out] */ EXCEPINFO __RPC_FAR *pExcepInfo,
            /* [out] */ UINT __RPC_FAR *puArgErr);
        
        END_INTERFACE
    } _IAtlTimerCtrlEventsVtbl;

    interface _IAtlTimerCtrlEvents
    {
        CONST_VTBL struct _IAtlTimerCtrlEventsVtbl __RPC_FAR *lpVtbl;
    };

    

#ifdef COBJMACROS


#define _IAtlTimerCtrlEvents_QueryInterface(This,riid,ppvObject)	\
    (This)->lpVtbl -> QueryInterface(This,riid,ppvObject)

#define _IAtlTimerCtrlEvents_AddRef(This)	\
    (This)->lpVtbl -> AddRef(This)

#define _IAtlTimerCtrlEvents_Release(This)	\
    (This)->lpVtbl -> Release(This)


#define _IAtlTimerCtrlEvents_GetTypeInfoCount(This,pctinfo)	\
    (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo)

#define _IAtlTimerCtrlEvents_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo)

#define _IAtlTimerCtrlEvents_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)

#define _IAtlTimerCtrlEvents_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* ___IAtlTimerCtrlEvents_DISPINTERFACE_DEFINED__ */


#ifdef __cplusplus
EXTERN_C const CLSID CLSID_AtlTimerCtrl;

class DECLSPEC_UUID("EE6E4F32-B113-11D0-8023-006097418C73")
AtlTimerCtrl;
#endif

#ifdef __cplusplus
EXTERN_C const CLSID CLSID_AtlTimerProp;

class DECLSPEC_UUID("831B59A1-B1DD-11D0-8026-006097418C73")
AtlTimerProp;
#endif
#endif /* __ATLTIMERLib_LIBRARY_DEFINED__ */

/* Additional Prototypes for ALL interfaces */

/* end of Additional Prototypes */

#ifdef __cplusplus
}
#endif

#endif
